package Daje::Workflow::GenerateSQL::Base::Common;
use Mojo::Base -base, -signatures;

has 'json' ;
has 'templates' ;
has 'sql' ;
has 'index' => 0;
has 'version' ;
has 'error';

sub shift_section ($self, $array) {
    my $result = {};
    my $test = ref $array;
    if (ref $array eq 'ARRAY') {
        $result = shift(@{$array});
    }
    return $result;
}

sub set_sql($self, $sqlin) {
    $self->sql($sqlin);
}


1;











#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME

Daje::Workflow::GenerateSQL::Base::Common


=head1 DESCRIPTION

pod generated by Pod::Autopod - keep this line to make pod updates possible ####################


=head1 REQUIRES

L<Mojo::Base> 


=head1 METHODS

=head2 set_sql($self,

 set_sql($self,();

=head2 shift_section

 shift_section();


=cut

